<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.UI.Xaml.Controls.AnimatedVisuals

Windows Runtime (WinRT) APIs for for the `Microsoft.UI.Xaml.Controls.AnimatedVisuals` namespace.

This package provides the `winrt.microsoft.ui.xaml.controls.animatedvisuals` module.
